"use strict";

const argx = require('argx'),
    async = require('async'),
    apemanfile = require('apemanfile'),
    apemancwd = require('apemancwd'),
    listInfrs = require('./infring/list_infrs'),
    buildInfrs = require('./infring/build_infrs'),
    removeInfrs = require('./infring/remove_infrs');

/** @lends apemanInfr */
function apemanInfr(options, callback) {
    let args = argx(arguments);
    callback = args.pop('function') || argx.noop;
    options = args.pop('object') || {};

    let cwd = apemancwd.create({prefix: 'apeman-infr'});

    async.waterfall([
        (callback) => {
            apemanfile.load(options.configuration, callback);
        },
        (apemanfile, callback) => {
            cwd.chdir(apemanfile.$cwd);
            if (options.list) {
                listInfrs(apemanfile, {
                    pattern: options.pattern
                }, callback);
                return;
            }
            if (options.delete) {
                removeInfrs(apemanfile, {
                    pattern: options.pattern,
                    force: options.force
                }, callback);
                return;
            }
            buildInfrs(apemanfile, {
                pattern: options.pattern,
                force: options.force
            }, callback);
        }
    ], (err) => {
        cwd.restoreAll();
        callback(err);
    });
}


module.exports = apemanInfr;
