/**
 * @memberof module:apeman-infr
 * @function getInfrs * @param {Apemanfile} apemanfile
 * @param {string[]} names
 * @param {function} callback
 */

"use strict";

const arrayreduce = require('arrayreduce'),
    arrayfilter = require('arrayfilter'),
    stringcase = require('stringcase'),
    minimatch = require('minimatch'),
    Infr = require('./infr'),
    apemandocker = require('apemandocker');

let rejectEmpty = arrayfilter.emptyReject(),
    concatArray = arrayreduce.arrayConcat();


/** @lends getInfrs */
function getInfrs(apemanfile, pattern) {
    let $pkg = apemanfile.$pkg;
    if (!$pkg) {
        throw new Error(`$pkg not found.`);
    }

    let $infrs = apemanfile.$infrs || {};

    return Object.keys($infrs)
        .filter((name) => {
            let rejected = pattern && !minimatch(name, pattern);
            return !rejected;
        })
        .map((name) => {
            let infra = $infrs[name];
            return [].concat(infra || [])
                .reduce(concatArray, [])
                .filter(rejectEmpty)
                .map((src, i) => {
                    return new Infr(src, {
                        name: name,
                        tag: apemandocker.nameImage($pkg, i > 0 ? [name, i].join('-') : name)
                    });
                })
        })
        .sort((a, b) => {
            return a.tag.localeCompare(b.tag);
        })
        .reduce(concatArray, []);
}

module.exports = getInfrs;